package cn.com.qmth.examcloud.core.basic.service.cache;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.qmth.examcloud.commons.exception.StatusException;
import cn.com.qmth.examcloud.commons.util.UrlUtil;
import cn.com.qmth.examcloud.core.basic.dao.StudentRepo;
import cn.com.qmth.examcloud.core.basic.dao.entity.StudentEntity;
import cn.com.qmth.examcloud.support.cache.bean.StudentCacheBean;
import cn.com.qmth.examcloud.web.bootstrap.PropertyHolder;
import cn.com.qmth.examcloud.web.cache.RandomObjectRedisCache;
import cn.com.qmth.examcloud.web.helpers.GlobalHelper;

@Service
public class StudentCache extends RandomObjectRedisCache<StudentCacheBean> {

	@Autowired
	StudentRepo studentRepo;

	@Override
	public StudentCacheBean loadFromResource(Object... keys) {
		Long studentId = (Long) keys[0];

		StudentEntity s = GlobalHelper.getPresentEntity(studentRepo, studentId,
				StudentEntity.class);

		StudentCacheBean b = new StudentCacheBean();
		b.setId(s.getId());
		b.setEnable(s.getEnable());
		b.setIdentityNumber(s.getIdentityNumber());
		b.setName(s.getName());
		b.setOrgId(s.getOrgId());
		b.setPhoneNumber(s.getPhoneNumber());
		b.setRemark(s.getRemark());
		b.setRootOrgId(s.getRootOrgId());
		b.setSecurityPhone(s.getSecurityPhone());

		if (StringUtils.isNotBlank(s.getPhotoPath())) {
			String upyunDomain = PropertyHolder.getString("$upyun.site.1.domain");
			if (StringUtils.isBlank(upyunDomain)) {
				throw new StatusException("560111",
						"property[$upyun.site.1.domain] is not configured");
			}
			String path = UrlUtil.joinUrl(upyunDomain, "student_base_photo", s.getPhotoPath());
			b.setPhotoPath(path);
		}

		return b;
	}

	@Override
	protected String getKeyPrefix() {
		return "B_STUDENT:";
	}

	@Override
	protected int getTimeout() {
		// 5分钟
		return 60 * 5;
	}

}
